Tango Photos
=====

Tango-Photos is a reusable app for photo galleries in Django. While it forms a key component of Tango, it can also be dropped into an existing non-Tango project. 


##Installation:

    pip install tango-photos 

or

    pip install git+https://github.com/tBaxter/tango-photos.git

tango_shared is a dependency. It will be installed. 

## Usage:
Add 'photos' and 'tango_shared' to your installed apps, then run syncdb or migrate.
